/*
ͻ
 What's it called: EPMTeX V1.1                                              
                                                                            
 What does it do:  The E source code for the EPMTeX enhancements V1.1       
                   for EPM.                                                                                                                             
                                                                            
 Who and When:     Jon Hacker 1/93                                          
                                                                            
ͼ
*/



const
/*
------------------------------------------------------------------------------------
NOTE:  For reasons of speed, I do not load the command processor in spawned
       shells by specifying the /n option in the start command.  This means that
       batch files will not run ( ie. TEX_EXEC=d:\mytex\texit.cmd ) since there
       is no interpreter!  If you want to run batch files (slow!) then delete
       the /n parameter in the 'start' commands in tex.e.

       If you want to run a previewer that is not a PM application, add the
       switch /win or /fs as appropriate in the start command in procedures
       tex_view_portrait and tex_view_landscape.

------------------------------------------------------------------------------------
*/
/* put your TeX executable path, filename and args here */
TEX_EXEC = 'd:\emtex\bin\tex386.exe ^&plain'

/* put your Previewer (portrait mode) executable path, filename and args here */
TEX_VIEW_EXEC = 'd:\emtex\dviscr\dvipm7.exe @d:\emtex\dviscr\dvipm.cnf'

/* put your Previewer (landscape mode) executable path, filename and args here */
TEX_VIEWLA_EXEC = 'd:\emtex\dviscr\dvipm7.exe @d:\emtex\dviscr\dvipm.cnf'

/* put your DVI Driver (portrait mode) executable path, filename and args here */
TEX_PRINT_PORTRAIT_EXEC = 'd:\emtex\dvidrv\dvihplj7.exe @d:\emtex\dvidrv\lj.cnf'

/* put your DVI Driver (landscape mode) executable path, filename and args here */
TEX_PRINT_LANDSCAPE_EXEC = 'd:\emtex\dvidrv\dvihplj7.exe @d:\emtex\dvidrv\lj.cnf /tr1'


--------------------------------------------------------------------------------------

compile if not defined(TEX_AUTO_DELETE_LOG)
const   TEX_AUTO_DELETE_LOG = 1               -- 0 to turn off log file auto-delete
compile endif

compile if not defined(TEX_AUTO_SAVE_DOC)
const   TEX_AUTO_SAVE_DOC = 1                  -- 0 to turn off smart save before TeX
compile endif

compile if not defined(TEX_DEBUG_MODE)
const   TEX_DEBUG_MODE = 0                  -- 1 to turn on verbose mode for debugging TeX 
compile endif
--------------------------------------------------------------------------------------

definit
    universal tex_auto_log
    universal tex_auto_save
    universal tex_debug

    tex_auto_log=TEX_AUTO_DELETE_LOG
    tex_auto_save=TEX_AUTO_SAVE_DOC
    tex_debug=TEX_DEBUG_MODE

--------------------------------------------------------------------------------------
-- English language support for TeX menu help

const
TEX_BARP__MSG = \1'Menus related to TeX support'
TEX_TEXP__MSG = \1'TeX the current file'
TEX_VIEWP__MSG = \1'Preview the current associated DVI file (Portrait)'
TEX_VIEWLAP__MSG = \1'Preview the current associated DVI file Landscape)'
TEX_PRP__MSG = \1'Print the current associated DVI output file (Portrait)'
TEX_PRLAP__MSG = \1'Print the current associated DVI output file (Landscape)'
TEX_DLOGP__MSG = \1'Delete the current associated LOG file'
TEX_DDVIP__MSG = \1'Delete the current associated DVI file'
TEX_ADLOGP__MSG = \1'Automatic delete of the associated LOG file after View or Print'
TEX_ASAVEP__MSG = \1'Automatic smart save of TeX file before TeXing document.'
TEX_DEBUGP__MSG = \1'Verbose mode for troubleshooting TeX commands.'

-------------------------------------------------------------------------------
-- Define TeX menu system

defload 
  universal defaultmenu
    universal tex_auto_log
  buildsubmenu defaultmenu, 9, '~TeX', TEX_BARP__MSG, 0,0
     buildmenuitem defaultmenu, 9, 901, '~TeX Document',   'tex'TEX_TEXP__MSG, 0,0
     buildmenuitem defaultmenu, 9, 902, \0, '', 4, 0
     buildmenuitem defaultmenu, 9, 903, 'Pre~View Portrait','texvw'TEX_VIEWP__MSG,  0,4
     buildmenuitem defaultmenu, 9, 904, 'PreVie~W Landscape','texvwla'TEX_VIEWLAP__MSG, 0,0
     buildmenuitem defaultmenu, 9, 905, \0, '', 4, 0
     buildmenuitem defaultmenu, 9, 906, '~Print Portrait', 'texpr'TEX_PRP__MSG,  0,0
     buildmenuitem defaultmenu, 9, 907, 'Print ~Landscape','texprla'TEX_PRLAP__MSG, 0,0
     buildmenuitem defaultmenu, 9, 908, \0, '', 4, 0
     buildmenuitem defaultmenu, 9, 909, 'Delete LO~G File','tex_del_log'TEX_DLOGP__MSG, 0,0
     buildmenuitem defaultmenu, 9, 910, 'Delete ~DVI File','tex_del_dvi'TEX_DDVIP__MSG, 0,0
     buildmenuitem defaultmenu, 9, 911, \0, '', 4, 0
     buildmenuitem defaultmenu, 9, 912, '~Auto LOG Delete','toggle_auto_log'TEX_ADLOGP__MSG, 0,0
     buildmenuitem defaultmenu, 9, 913, 'Auto ~Save ','toggle_auto_save'TEX_ASAVEP__MSG, 0,0
     buildmenuitem defaultmenu, 9, 914, 'Debug mode ','toggle_debug'TEX_DEBUGP__MSG, 0,0

  showmenu defaultmenu


-------------------------------------------------------------------------------
--Command definitions
-------------------------------------------------------------------------------
-- Create a OS/2 window & execute TeX in it.
defc tex =
    universal tex_auto_save, tex_debug
    if .modify then               -- Modified since last Save?
       if tex_auto_save then      --  Want auto smart save feature?
           'Save'                 --   Yes - save it before TeXing document
            sayerror 'Saving modified document before calling TeX!'
       else                       --   No - warn user!
            sayerror 'TeXing stale document file... auto_save disabled!'
       endif
    endif
    n=lastpos('\',.filename)+1
    pathname=delstr(.filename,n-1)
    pathfile = translate(.filename, '/', '\')
    call directory(pathname)
    command=TEX_EXEC ' ' pathfile
    if tex_debug then
        sayerror command
    endif

-- NOTE: delete /n if you specify a batch file as your executable!

    'start /n /win 'command
    if rc <> 0 then
        sayerror"Caution! TeX_Document exited with return code = "rc
    endif
-------------------------------------------------------------------------------
-- View current TeX file in dvipm. (Portrait orientation)
defc texvw =
    universal tex_auto_log
    if  tex_auto_log then
        call tex_delete_log_file()
    endif
    call tex_view_portrait()


-------------------------------------------------------------------------------
-- View current TeX file in dvipm. (Landscape orientation)
defc texvwla =
    universal tex_auto_log
    if  tex_auto_log then
        call tex_delete_log_file()
    endif
    call tex_view_landscape()

-------------------------------------------------------------------------------
-- Create a OS/2 window & execute TeX printer driver (portrait mode) in it.
defc texpr =
    universal tex_auto_log
    if  tex_auto_log then
        call tex_delete_log_file()
    endif
    call tex_print_portrait()

-------------------------------------------------------------------------------
-- Create a OS/2 window & execute TeX printer driver (landscape mode) in it.
defc texprla =
    universal tex_auto_log
    if  tex_auto_log then
        call tex_delete_log_file()
    endif
    call tex_print_landscape()

-------------------------------------------------------------------------------
-- Delete current TeX LOG file.
defc tex_del_log = call tex_delete_log_file()

-------------------------------------------------------------------------------
-- Delete current TeX DVI file.
defc tex_del_dvi = call tex_delete_dvi_file()

-------------------------------------------------------------------------------
-- Toggle Auto-Delete current TeX LOG file after View or Print flag.
defc toggle_auto_log =
    universal tex_auto_log
    tex_auto_log = not tex_auto_log
    sayerror 'tex_auto_log = 'tex_auto_log

-------------------------------------------------------------------------------
-- Toggle Auto smart-save current TeX file before TeXing document .
defc toggle_auto_save =
    universal tex_auto_save
    tex_auto_save = not tex_auto_save
    sayerror 'tex_auto_save = 'tex_auto_save

-------------------------------------------------------------------------------
-- Toggle debug mode for troubleshooting TeX commands.
defc toggle_debug =
    universal tex_debug
    tex_debug = not tex_debug
    sayerror 'tex_debug = 'tex_debug

-------------------------------------------------------------------------------
--Procedure definitions
-------------------------------------------------------------------------------
-- Delete current TeX LOG file.
defproc tex_delete_log_file
    n=lastpos('\',.filename)+1;
    filename=substr(.filename,n);
    pathname=delstr(.filename,n-1);
    n=lastpos('.',filename)+1;
    stem=delstr(filename,n-1);
    rc = erasetemp(pathname'\'stem'.log')
    if rc = 0 then
       sayerror 'File 'stem'.LOG deleted'
    elseif rc = 2 then
        sayerror 'Delete LOG: file 'stem'.LOG could not be found'
    else
        sayerror 'Delete LOG: file 'stem'.LOG could not be deleted'
        beep(1000, 100)
    endif


-------------------------------------------------------------------------------
-- Delete current TeX DVI file.
defproc tex_delete_dvi_file
    n=lastpos('\',.filename)+1;
    filename=substr(.filename,n);
    pathname=delstr(.filename,n-1);
    n=lastpos('.',filename)+1;
    stem=delstr(filename,n-1);
    rc = erasetemp(pathname'\'stem'.dvi')
    if rc = 0 then
       sayerror 'File 'stem'.DVI deleted'
    elseif rc = 2 then
        sayerror 'Delete DVI: file 'stem'.DVI could not be found'
    else
        sayerror 'Delete DVI: file 'stem'.DVI could not be deleted'
        beep(1000, 100)
    endif

-------------------------------------------------------------------------------
-- View current TeX file in dvipm. (Portrait orientation)
defproc tex_view_portrait
    universal tex_debug
    n=lastpos('\',.filename)+1;
    filename=substr(.filename,n);
    pathname=delstr(.filename,n-1);
    n=lastpos('.',filename)+1;
    stem=delstr(filename,n-1);
    command= TEX_VIEW_EXEC' 'pathname'\'stem'.dvi'
    if tex_debug then
        sayerror command
    endif

-- NOTE: delete /n if you specify a batch file as your executable!

    'start /n 'command
    if rc > 0 then 
        sayerror"Caution! PreView_Portrait exited with return code = "rc
    endif

-------------------------------------------------------------------------------
-- View current TeX file in dvipm. (Landscape orientation)
defproc tex_view_landscape
    universal tex_debug
    n=lastpos('\',.filename)+1;
    filename=substr(.filename,n);
    pathname=delstr(.filename,n-1);
    n=lastpos('.',filename)+1;
    stem=delstr(filename,n-1);
    command= TEX_VIEWLA_EXEC' 'pathname'\'stem'.dvi'
    if tex_debug then
        sayerror command
    endif

-- NOTE: delete /n if you specify a batch file as your executable!

    'start /n 'command
    if rc > 0 then 
        sayerror"Caution! PreView_Landscape exited with return code = "rc
    endif

-------------------------------------------------------------------------------
-- Create a OS/2 window & execute TeX printer driver (portrait mode) in it.
defproc tex_print_portrait =
    universal tex_debug
    n=lastpos('\',.filename)+1;
    filename=substr(.filename,n);
    pathname=delstr(.filename,n-1);
    n=lastpos('.',filename)+1;
    stem=delstr(filename,n-1);
    command=TEX_PRINT_PORTRAIT_EXEC' 'pathname'\'stem'.dvi'
    if tex_debug then
        sayerror command
    endif

-- NOTE: delete /n if you specify a batch file as your executable!

    'start /n /win 'command
    if rc > 0 then 
        sayerror"Caution! Print_Portrait exited with return code = "rc
    endif

-------------------------------------------------------------------------------
-- Create a OS/2 window & execute TeX printer driver (Landscape mode) in it.
defproc tex_print_landscape =
    universal tex_debug
    n=lastpos('\',.filename)+1;
    filename=substr(.filename,n);
    pathname=delstr(.filename,n-1);
    n=lastpos('.',filename)+1;
    stem=delstr(filename,n-1);
    command=TEX_PRINT_LANDSCAPE_EXEC' 'pathname'\'stem'.dvi'
    if tex_debug then
        sayerror command
    endif

-- NOTE: delete /n if you specify a batch file as your executable!

    'start /n /win 'command
    if rc > 0 then 
        sayerror"Caution! Print_Landscape exited with return code = "rc
    endif

-------------------------------------------------------------------------------
-- called in mymnuini.e to get state of global TeX variable tex_auto_log

defproc get_tex_auto_log =
    universal tex_auto_log
    return tex_auto_log

-------------------------------------------------------------------------------
-- called in mymnuini.e to get state of global TeX variable tex_auto_save

defproc get_tex_auto_save =
    universal tex_auto_save
    return tex_auto_save

-------------------------------------------------------------------------------
-- called in mymnuini.e to get state of global TeX variable tex_debug

defproc get_tex_debug =
    universal tex_debug
    return tex_debug

-------------------------------------------------------------------------------

